@@ -8,6 +8,10 @@
 #include <libxklavier/xklavier.h>
 #include <libxklavier/xklavier_config.h>
 
+#ifdef HAVE_SETLOCALE
+# include <locale.h>
+#endif
+
 #ifdef __STRICT_ANSI__
 /* these are functions which are NOT in ANSI C. 
    Probably we should provide the implementation */
@@ -19,7 +23,7 @@ extern void XklConfigDump( FILE* file,
 
 enum { ACTION_NONE, ACTION_GET, ACTION_SET, ACTION_WRITE };
 
-static void printUsage()
+static void printUsage(void)
 {
   printf( "Usage: test_config (-g)|(-s -m <model> -l <layouts> -o <options>)|(-h)|(-ws)|(-wb)(-d <debugLevel>)\n" );
   printf( "Options:\n" );
@@ -87,6 +91,10 @@ int main( int argc, char * const argv[] )
     exit( 0 );
   }
 
+#ifdef HAVE_SETLOCALE
+  setlocale( LC_ALL, "" );
+#endif
+
   dpy = XOpenDisplay( NULL );
   if ( dpy == NULL )
   {
